.xprez-module {
	.btn {
		--ck-color-link-selected-background: #{$button-primary-bg};

		@if $use-xprez-button-styles {
			display: inline-block;
			@include type($button-size);
			font-family: $button-font-family;
			box-sizing: border-box;
			border-radius: $button-border-radius;
			text-shadow: $button-text-shadow;
			border: $button-border;
			text-decoration: $button-text-transform;
			text-transform: $button-text-transform;
			letter-spacing: $button-letter-spacing;
			padding: $button-padding-v $button-padding-h;
			color: $button-primary-text-color;
			background: $button-primary-bg;
			box-shadow: $button-box-shadow;

			@media only screen and (max-width: $typo-break-s) {
				padding: ($button-padding-v * 0.75) ($button-padding-h * 0.75);
			}

			&:active {
				transform: scale(0.95);
			}

			&:hover {
				color: $button-primary-hover-text-color;
				background: $button-primary-hover-bg;
			}

			&.btn-secondary {
				color: $button-secondary-text-color;
				background: $button-secondary-bg;

				&:hover {
					color: $button-secondary-hover-text-color;
					background: $button-secondary-hover-bg;
				}
			}

			&.btn-white {
				background: $white;
				color: $txt-gray;
				&:hover { color: $txt-gray; }
			}
		}

	}
}